@@ -8,7 +8,7 @@ use Moo;
 use MooX::Aliases;
 use namespace::clean;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 with 'Catmandu::Store';
 with 'Catmandu::Transactional';
@@ -80,7 +80,7 @@ sub dbh {
     my ($self)       = @_;
     my $dbh          = $self->_dbh;
     my $connect_time = $self->_connect_time;
-    my $driver = $dbh->{Driver}{Name} // '';
+    my $driver       = $dbh->{Driver}{Name} // '';
 
     # MySQL has builtin option mysql_auto_reconnect
     if (   $driver !~ /mysql/i
@@ -316,6 +316,21 @@ Only MySQL, PostgreSQL
 
 Only PostgreSQL
 
+This is mapped internally to postgres field of type "jsonb".
+
+Please use the serializer L<Catmandu::Serializer::json_string>,
+
+if you choose to store the perl data structure into this type of field.
+
+Reasons:
+
+* there are several types of serializers. E.g. serializer "messagepack"
+  produces a string that is not accepted by a jsonb field in postgres
+
+* the default serializer L<Catmandu::Serializer::json> converts the perl data structure to a binary json string,
+  and the DBI client reencodes that utf8 string (because jsonb is a sort of text field),
+  so you end up having a double encoded string.
+
 =back
 
 =head2 Column options
